summaryrefslogtreecommitdiffstats
path: root/ui/base/keycodes/keyboard_codes_posix.h
diff options
context:
space:
mode:
Diffstat (limited to 'ui/base/keycodes/keyboard_codes_posix.h')
-rw-r--r--ui/base/keycodes/keyboard_codes_posix.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/ui/base/keycodes/keyboard_codes_posix.h b/ui/base/keycodes/keyboard_codes_posix.h
index e7f679d..a2943e7 100644
--- a/ui/base/keycodes/keyboard_codes_posix.h
+++ b/ui/base/keycodes/keyboard_codes_posix.h
@@ -207,10 +207,12 @@ enum KeyboardCode {
VKEY_OEM_CLEAR = 0xFE,
VKEY_UNKNOWN = 0,
// POSIX specific VKEYs. Note that as of Windows SDK 7.1, 0xD8-DA are
// unassigned.
VKEY_BRIGHTNESS_DOWN = 0xD8,
- VKEY_BRIGHTNESS_UP = 0xD9
+ VKEY_BRIGHTNESS_UP = 0xD9,
+ VKEY_KBD_BRIGHTNESS_DOWN = 0xDA,
+ VKEY_KBD_BRIGHTNESS_UP = 0xE8
};
} // namespace ui
@@ -207,10 +207,12 @@ enum KeyboardCode {
VKEY_OEM_CLEAR = 0xFE,
VKEY_UNKNOWN = 0,
- // POSIX specific VKEYs. Note that as of Windows SDK 7.1, 0xD8-DA are
+ // POSIX specific VKEYs. Note that as of Windows SDK 7.1, 0xD8-DA and 0xE8 are
// unassigned.
VKEY_BRIGHTNESS_DOWN = 0xD8,